[libvirt PATCH 2/4] vmx: shortcut 'cdrom-image' as CD-ROM earlier

Pino Toscano ptoscano at redhat.com
Mon Oct 12 15:13:46 UTC 2020


Add it to the list of 'deviceType' values ignored for disks.

Signed-off-by: Pino Toscano <ptoscano at redhat.com>
---
 src/vmx/vmx.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/src/vmx/vmx.c b/src/vmx/vmx.c
index 70f4d78e8a..0ec6222f50 100644
--- a/src/vmx/vmx.c
+++ b/src/vmx/vmx.c
@@ -2235,13 +2235,15 @@ virVMXParseDisk(virVMXContext *ctx, virDomainXMLOptionPtr xmlopt, virConfPtr con
             (deviceType &&
              (STRCASEEQ(deviceType, "atapi-cdrom") ||
               STRCASEEQ(deviceType, "cdrom-raw") ||
+              STRCASEEQ(deviceType, "cdrom-image") ||
               (STRCASEEQ(deviceType, "scsi-passthru") &&
                STRPREFIX(fileName, "/vmfs/devices/cdrom/"))))) {
             /*
              * This function was called in order to parse a harddisk device,
              * but .iso files, 'atapi-cdrom', 'cdrom-raw', and 'scsi-passthru'
              * CDROM devices are for CDROM devices only. Just ignore it, another
              * call to this function to parse a CDROM device may handle it.
              */
             goto ignore;
         } else if (virStringHasCaseSuffix(fileName, ".vmdk")) {
@@ -2235,13 +2235,15 @@ virVMXParseDisk(virVMXContext *ctx, virDomainXMLOptionPtr xmlopt, virConfPtr con
             /*
              * This function was called in order to parse a harddisk device,
-             * but .iso files, 'atapi-cdrom', 'cdrom-raw', and 'scsi-passthru'
-             * CDROM devices are for CDROM devices only. Just ignore it, another
-             * call to this function to parse a CDROM device may handle it.
+             * but .iso files, 'atapi-cdrom', 'cdrom-raw', 'cdrom-image',
+             * and 'scsi-passthru' CDROM devices are for CDROM devices only.
+             * Just ignore it, another call to this function to parse a CDROM
+             * device may handle it.
              */
             goto ignore;
-- 
2.26.2




More information about the libvir-list mailing list